'*******************************************************************************
'*    Description : DIGITAL MELODY PLAYER                                      *
'*    Revision    : 1.0                                                        *
'*    Controller  : ATMEGA88                                                   *
'*    Compiler    : BASCOM-AVR 1.11.8.7 DEMO                                   *
'*    Author      : Rubashka Vasiliy , Ukraine , 2007                          *
'*    Web         : HTTP://WWW.LEDEFFECTS.NET                                  *
'*******************************************************************************
'                _______________          |*\_/*|________
'               |  ___________  |        ||_/-\_|______  |
'               | |           | |        | |           | |
'               | |   0   0   | |        | |   0   0   | |
'               | |     -     | |        | |     -     | |
'               | |   \___/   | |        | |   \___/   | |
'               | |___     ___| |        | |___________| |
'               |_____|\_/|_____|        |_______________|
'                 _|__|/ \|_|_.............._|________|_
'                / ********** \            / ********** \
'              /  ************  \        /  ************  \
'              - - - - - - - - - -      - - - - - - - - - - -
'      _______________________________________________________________
'     | |C||D| | |F||G||A| | |C||D| | |F||G||A| | |C||D| | |F||G||A| |\
'     | |1||1| | |1||1||1| | |2||2| | |2||2||2| | |3||3| | |3||3||3| | |
'     | |#||#| | |#||#||#| | |#||#| | |#||#||#| | |#||#| | |#||#||#| | |
'     |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  | |
'     |C1|D1|E1|F1|G1|A1|H1|C2|D2|E2|F2|G2|A2|H2|C3|D3|E3|F3|G3|A3|H3| |
'     |__|__|__|__|__|__|__|__|__|__|__|__|__|__|__|__|__|__|__|__|__| |
'      \__\__\__\__\__\__\__\__\__\__\__\__\__\__\__\__\__\__\__\__\__\|
'
'*******************************************************************************
' Conditional marking a writing the tunes compatible with telephones "Siemens"
'*******************************************************************************
'
' *****            NOTES             *****
'
' A       - La
' Ais(#)  - La diez
' B(H)    - Si
'        - Do
' is(#)  - Do diez
' D       - Re
' Dis(#)  - Re diez
' E       - Mi
' F       - Fa
' Fis(#)  - Fa diez
' G       - Sol
' Gis(#)  - Sol diez
'
' *****            OKTAVE            *****
'
' 1       - 1 octave
' 2       - 2 octave
' 3       - 3 octave
'
' *****      DURATION OF PAUSES      *****
'
' P(1/1)   - 2           - Wait 2
' P(1/2)   - 1           - Wait 1
' P(1/4)   - 0,5         - Waitms 500
' P(1/8)   - 0,25        - Waitms 250
' P(1/16)  - 0,125       - Waitms 125
' P(1/32)  - 0,0625      - Waitms 63
'
' *****      DURATION OF NOTES       *****
'
' (1/1)   - 2 sec
' (1/2)   - 1 sec
' (1/4)   - 0,5 sec
' (1/8)   - 0,25 sec
' (1/16)  - 0,125 sec
' (1/32)  - 0,0625 sec
'
' *****   FORMAT TO FUNCTIONS SOUND  *****
'
' Sound Speaker , Pulses , Periods
' Speaker - port for generations of sound
' Periods - sound frequency (1-65535)
' Pulses  - duration of sound (1-65535)
'
' Periods = Abc[F_crystal / (k * F_nota)]
' Pulses  = Abc[(T_period * F_crystal) / (k * Periods)]
'
' F_crystal - clockrate of controller, Hz
' F_nota    - frequency a notes, Hz
' k = 12    - amount of tacts, for which is formed one period of sound
' T_period  - duration of sounding a notes, sec
' Abc       - function of truncation whole number
'
'===============================================================================
' Table of values Pulses,Periods for 3 octaves at frequency of quartz 8000000 Hz
'===============================================================================
'Note|Freqvency|Periods|Pulses 1/1|Pulses 1/2|Pulses 1/4|Pulses 1/8|Pulses 1/16|
'===============================================================================
' C1 |  261,63 |  2548 |    523   |    262   |    131   |    65    |     33    |
'Cis1|  277,18 |  2405 |    554   |    277   |    139   |    69    |     35    |
' D1 |  293,66 |  2270 |    587   |    294   |    147   |    73    |     37    |
'Dis1|  311,13 |  2143 |    622   |    311   |    156   |    78    |     39    |
' E1 |  329,63 |  2022 |    659   |    330   |    165   |    82    |     41    |
' F1 |  349,23 |  1909 |    698   |    349   |    175   |    87    |     44    |
'Fis1|  369,99 |  1802 |    740   |    370   |    185   |    92    |     46    |
' G1 |  392,00 |  1701 |    784   |    392   |    196   |    98    |     49    |
'Gis1|  415,30 |  1605 |    831   |    415   |    208   |   104    |     52    |
' A1 |  440,00 |  1515 |    880   |    440   |    220   |   110    |     55    |
'Ais1|  466,16 |  1430 |    932   |    466   |    233   |   117    |     58    |
' B1 |  493,88 |  1350 |    988   |    494   |    247   |   124    |     62    |
'===============================================================================
' C2 |  523,25 |  1274 |   1047   |    523   |    262   |   131    |     65    |
'Cis2|  554,36 |  1203 |   1109   |    554   |    277   |   139    |     69    |
' D2 |  587,32 |  1135 |   1175   |    587   |    294   |   147    |     73    |
'Dis2|  622,26 |  1071 |   1245   |    622   |    311   |   156    |     78    |
' E2 |  659,26 |  1011 |   1319   |    659   |    330   |   165    |     82    |
' F2 |  698,46 |   954 |   1397   |    698   |    349   |   175    |     87    |
'Fis2|  739,98 |   901 |   1480   |    740   |    370   |   185    |     92    |
' G2 |  784,00 |   850 |   1568   |    784   |    392   |   196    |     98    |
'Gis2|  830,60 |   803 |   1661   |    831   |    415   |   208    |    104    |
' A2 |  880,00 |   758 |   1720   |    880   |    440   |   220    |    110    |
'Ais2|  932,32 |   715 |   1865   |    932   |    466   |   233    |    117    |
' B2 |  987,75 |   675 |   1976   |    988   |    494   |   247    |    124    |
'===============================================================================
' C3 | 1046,50 |   637 |   2093   |   1047   |    523   |   262    |    131    |
'Cis3| 1108,70 |   601 |   2218   |   1109   |    554   |   277    |    139    |
' D3 | 1174,60 |   566 |   2350   |   1175   |    587   |   294    |    147    |
'Dis3| 1244,50 |   536 |   2490   |   1245   |    622   |   311    |    156    |
' E3 | 1318,50 |   483 |   2638   |   1319   |    659   |   330    |    165    |
' F3 | 1396,90 |   477 |   2794   |   1397   |    698   |   349    |    175    |
'Fis3| 1480,00 |   450 |   2960   |   1480   |    740   |   370    |    185    |
' G3 | 1568,00 |   425 |   3136   |   1568   |    784   |   392    |    196    |
'Gis3| 1661,20 |   401 |   3322   |   1661   |    831   |   415    |    208    |
' A3 | 1720,00 |   388 |   3440   |   1720   |    880   |   440    |    220    |
'Ais3| 1864,60 |   358 |   3730   |   1865   |    932   |   466    |    233    |
' B3 | 1975,50 |   337 |   3952   |   1976   |    988   |   494    |    247    |
'===============================================================================
$regfile = "m88def.dat"
$crystal = 8000000
$hwstack = 40
$swstack = 40
$framesize = 40

Config Portb.7 = Output
Speaker Alias Portb.7
'===============================================================================
'                    _______
'      |     ____    |_____|   |
'  PB.0|----|____|----|+ -|----| GND
'      |              |___|    |
'      |    100    Speaker
'
'===============================================================================

Do

'Europe :: Final Countdown
   Sound Speaker , 124 , 675                                   'H2(1/16)
   Sound Speaker , 110 , 758                                   'A2(1/16)
   Sound Speaker , 248 , 675                                   'H2(1/8)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 165 , 1011                                  'E2(1/8)
   Waitms 250                                                  'P(1/8)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 131 , 637                                   'C3(1/16)
   Sound Speaker , 124 , 675                                   'H2(1/16)
   Sound Speaker , 131 , 637                                   'C3(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 124 , 675                                   'H2(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 220 , 758                                   'A2(1/8)
   Waitms 125                                                  'P(1/16)
   Waitms 250                                                  'P(1/8)
   Sound Speaker , 131 , 637                                   'C3(1/16)
   Sound Speaker , 124 , 675                                   'H2(1/16)
   Sound Speaker , 262 , 637                                   'C3(1/8)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 165 , 1011                                  'E2(1/8)
   Waitms 250                                                  'P(1/8)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 110 , 758                                   'A2(1/16)
   Sound Speaker , 98 , 850                                    'G2(1/16)
   Sound Speaker , 110 , 758                                   'A2(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 98 , 850                                    'G2(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 92 , 901                                    'Fis2(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 110 , 758                                   'A2(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 196 , 850                                   'G2(1/8)
   Wait 2

'Corona :: Rythm of The Night
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 87 , 954                                    'F2(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 98 , 850                                    'G2(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 87 , 954                                    'F2(1/16)
   Sound Speaker , 117 , 715                                   'Ais2(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 110 , 758                                   'A2(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 98 , 850                                    'G2(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 110 , 758                                   'A2(1/16)
   Sound Speaker , 87 , 954                                    'F2(1/16)
   Waitms 125                                                  'P(1/16)
   Wait 2

'Jean Michel Jarre :: Oxygene 10
   Sound Speaker , 131 , 637                                   'C3(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 92 , 901                                    'Fis2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 131 , 637                                   'C3(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 92 , 901                                    'Fis2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 117 , 715                                   'Ais2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 92 , 901                                    'Fis2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 104 , 803                                   'Gis2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 92 , 901                                    'Fis2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 98 , 850                                    'G2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 92 , 901                                    'Fis2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 98 , 850                                    'G2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 92 , 901                                    'Fis2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 98 , 850                                    'G2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 92 , 901                                    'Fis2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 98 , 850                                    'G2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Sound Speaker , 92 , 901                                    'Fis2(1/16)
   Sound Speaker , 65 , 1274                                   'C2(1/16)
   Wait 2

'Titanic: Theme
   Sound Speaker , 131 , 637                                   'C3(1/16)
   Sound Speaker , 147 , 566                                   'D3(1/16)
   Sound Speaker , 330 , 483                                   'E3(1/8)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 175 , 477                                   'F3(1/16)
   Sound Speaker , 165 , 483                                   'E3(1/16)
   Sound Speaker , 147 , 566                                   'D3(1/16)
   Sound Speaker , 131 , 637                                   'C3(1/16)
   Sound Speaker , 147 , 566                                   'D3(1/16)
   Sound Speaker , 392 , 425                                   'G3(1/8)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 165 , 483                                   'E3(1/16)
   Sound Speaker , 147 , 566                                   'D3(1/16)
   Sound Speaker , 262 , 637                                   'C3(1/8)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 110 , 758                                   'A2(1/16)
   Sound Speaker , 87 , 954                                    'F2(1/16)
   Sound Speaker , 196 , 850                                   'G2(1/8)
   Waitms 125                                                  'P(1/16)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 131 , 637                                   'C3(1/16)
   Sound Speaker , 147 , 566                                   'D3(1/16)
   Sound Speaker , 330 , 483                                   'E3(1/8)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 175 , 477                                   'F3(1/16)
   Sound Speaker , 165 , 483                                   'E3(1/16)
   Sound Speaker , 147 , 566                                   'D3(1/16)
   Sound Speaker , 131 , 637                                   'C3(1/16)
   Sound Speaker , 147 , 566                                   'D3(1/16)
   Sound Speaker , 392 , 425                                   'G3(1/8)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 165 , 483                                   'E3(1/16)
   Sound Speaker , 196 , 425                                   'G3(1/16)
   Sound Speaker , 440 , 388                                   'A3(1/8)
   Waitms 125                                                  'P(1/16)
   Sound Speaker , 196 , 425                                   'G3(1/16)
   Sound Speaker , 165 , 483                                   'E3(1/16)
   Sound Speaker , 294 , 566                                   'D3(1/8)
   Wait 2

Loop

'===============================================================================
' SIEMENS TUNES
'===============================================================================

' A1 :: Take On Me
'P(1/8) Ais1(1/16) Ais1(1/16) Ais1(1/16) Fis1(1/8) Dis1(1/8) Gis1(1/8) Gis1(1/8) Gis1(1/16) C2(1/16) C2(1/16) Cis2(1/16) Dis2(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16) Gis1(1/8) Fis1(1/8) Ais1(1/8) Ais1(1/8) Ais1(1/16) Gis1(1/16) Gis1(1/16) Ais1(1/16) Gis1(1/16) Ais1(1/16) Ais1(1/16) Ais1(1/16) Fis1(1/8) Dis1(1/8) Gis1(1/8) Gis1(1/8) Gis1(1/16) C2(1/16) C2(1/16) Cis2(1/16) Dis2(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16) Gis1(1/8) Fis1(1/8) Ais1(1/8) Ais1(1/8)

'Ace of Base :: Happy Nation
'D3(1/16) E2(1/16) E2(1/16) D2(1/16) D2(1/8) E2(1/16) E2(1/16) E2(1/16) E2(1/16) E2(1/8) G2(1/8) F2(1/8) E2(1/8) E2(1/8) E2(1/16) F2(1/16) P(1/16) P(1/16) F2(1/8) A2(1/8) G2(1/8) F2(1/8) E2(1/8) D2(1/8) E2(1/8) P(1/16) G2(1/8) P(1/16) F2(1/16) E2(1/16) E2(1/16) D2(1/8) Cis2(1/8) D2(1/8) D2(1/8) D2(1/8) E2(1/8) E2(1/8) D2(1/8) D2(1/8)

'Ace of Base :: Beautiful Life
'G2(1/16) F2(1/16) G2(1/16) F2(1/16) G2(1/16) Gis2(1/16) P(1/16) Dis2(1/8) Dis2(1/8) G2(1/8) D2(1/16) P(1/8) F2(1/16) Fis2(1/16) F2(1/16) Fis2(1/16) F2(1/16) G2(1/16) P(1/16) G2(1/16) G2(1/16) Gis2(1/16) G2(1/8) F2(1/16) Fis2(1/16)

'Ace of Base :: All That She Wants
'A2(1/8) P(1/16) A2(1/8) P(1/16) A2(1/8) C3(1/16) A2(1/16) C3(1/8) A2(1/8) P(1/8) A2(1/8) P(1/16) A2(1/8) P(1/16) A2(1/8) D3(1/16) A2(1/16) D3(1/8) A2(1/8) C3(1/8) A2(1/8) P(1/16) A2(1/8) P(1/16) A2(1/8) C3(1/16) A2(1/16) C3(1/8) A2(1/8) P(1/8) G2(1/8)

'Abba :: Waterloo
'H2(1/16) H2(1/16) A2(1/16) A2(1/8) P(1/16) H2(1/16) H2(1/16) H2(1/16) A2(1/16) G2(1/16) G2(1/16) G2(1/16) Fis2(1/16) Fis2(1/16) Fis2(1/16) G2(1/16) G2(1/8) P(1/16) H2(1/16) H2(1/16) A2(1/16) A2(1/8) P(1/16) H2(1/16) H2(1/16) H2(1/16) A2(1/16) H2(1/16) H2(1/16) H2(1/16) A2(1/16) G2(1/16) G2(1/16) Fis2(1/16) Fis2(1/16)

'Abba :: Thank Your For The Music
'D2(1/8) D2(1/8) D2(1/8) G2(1/16) G2(1/16) G2(1/16) Fis2(1/16) C2(1/16) H2(1/8) E2(1/16) G2(1/8) Fis2(1/8) A2(1/16) G2(1/8) Fis2(1/8) E2(1/16) Fis2(1/16) G2(1/16) H2(1/8) A2(1/8) G2(1/16) Fis2(1/8)

'Abba :: Ring Ring
'C2(1/8) P(1/8) P(1/16) C2(1/8) P(1/8) C2(1/16) D2(1/16) E2(1/16) F2(1/8) E2(1/16) D2(1/16) D2(1/8)

'Abba :: Money Money
'A2(1/8) H2(1/8) C3(1/8) A2(1/8) H2(1/8) C3(1/8) P(1/4) C3(1/8) A2(1/8) H2(1/8) C3(1/8) P(1/4) H2(1/8) A2(1/8) C3(1/8) C3(1/8) P(1/8) A2(1/8)

'Abba :: Mamma Mia
'C2(1/8) F2(1/8) E2(1/16) F2(1/16) G2(1/16) A2(1/8) P(1/16) F2(1/16) F2(1/16) E2(1/16) F2(1/16) E2(1/16) D2(1/8) P(1/16) G2(1/16) F2(1/16) G2(1/16) F2(1/16) P(1/16) F2(1/16) P(1/16) P(1/16) Ais2(1/16) Ais2(1/16) A2(1/16) F2(1/16) G2(1/16) F2(1/16)

'Abba :: Gimme Gimme Gimme
'D2(1/16) A2(1/16) D3(1/16) P(1/16) D3(1/16) A2(1/16) D2(1/8) P(1/4) P(1/8) P(1/16) D2(1/16) A2(1/16) D3(1/16) P(1/16) D3(1/16) A2(1/16) D2(1/16) E2(1/16) F2(1/16) G2(1/16) A2(1/8)

'Aerosmith :: Walk This Way
'F2(1/16) Fis2(1/16) G2(1/16) C3(1/8) F2(1/16) Fis2(1/16) G2(1/16) C3(1/8) C2(1/16) P(1/4) P(1/16) F2(1/16) Fis2(1/16) G2(1/16) C3(1/8) F2(1/16) Fis2(1/16) G2(1/16) C3(1/8) C2(1/8) C3(1/8)

'Agata Kristi : Chernaia Luna
'E2(1/8) E2(1/8) Gis2(1/8) A2(1/8) P2(1/8) C3(1/8) H2(1/8) A2(1/8) E2(1/8) E2(1/8) Gis2(1/8) A2(1/8) P2(1/8) C3(1/8) H2(1/8) A2(1/8) F2(1/8) F2(1/8) Gis2(1/8) A2(1/8) P2(1/8) F2(1/8) Gis2(1/8) A2(1/8) C3(1/8) C3(1/8) H2(1/8) H2(1/8) A2(1/8) A2(1/8) Gis2(1/8) Gis2(1/8) A2(1/2)

'Agata Kristi : Opium dlya nikogo
'G2(1/8) Dis3(1/4) D3(1/8) H2(1/8) G2(1/4) P(1/8) G2(1/8) Dis3(1/4) D3(1/8) H2(1/8) G2(1/4) P(1/8) G2(1/8) G2(1/8) G2(1/8) Gis2(1/8) G2(1/8) F2(1/8) G2(1/4) H2(1/4) D3(1/4) P(1/4) G2(1/8) Dis3(1/4) D3(1/8) H2(1/8) G2(1/4) P(1/8) G2(1/8) Dis3(1/4) D3(1/8) H2(1/8) G2(1/4) P(1/4) G2(1/8) G2(1/8) G2(1/8)

'Beatles :: All You Need Is Love
'D3(1/16) D3(1/16) D3(1/16) D3(1/8) D3(1/8) P(1/8) D3(1/16) D3(1/16) D3(1/16) D3(1/8) D3(1/8) P(1/8) D3(1/16) D3(1/16) Dis3(1/16) E3(1/16) E3(1/8) P(1/16) H2(1/8) P(1/8) A2(1/16) H2(1/16) A2(1/8) G2(1/16) G2(1/8)

'Backstreet Boys :: As Long As You ...
'Gis2(1/16) P(1/16) Gis2(1/8) G2(1/8) F2(1/8) G2(1/8) P(1/4) P(1/8) G2(1/8) G2(1/8) Gis2(1/8) Ais2(1/8) Dis2(1/8) P(1/2) P(1/4) C2(1/8) Dis2(1/8) P(1/8) F2(1/8) G2(1/8) F2(1/8) P(1/8) Dis2(1/8)

'Backstreet Boys :: Get Down
'A2(1/8) E2(1/8) P(1/8) E2(1/8) F2(1/8) E2(1/8) P(1/8) E2(1/8) Gis2(1/8) E2(1/8) P(1/8) F2(1/8) F2(1/8) E2(1/8) Dis2(1/8) E2(1/8) A2(1/8) E2(1/8) P(1/8) E2(1/8) F2(1/8) E2(1/8) P(1/8) E2(1/8) Gis2(1/8) E2(1/8) A2(1/8) H2(1/8) C3(1/8) P(1/8) H2(1/8)

'Bailando
'A2(1/8) G2(1/8) E2(1/8) C3(1/16) H2(1/8) G2(1/16) P(1/16) E2(1/16) G2(1/16) G2(1/16) E2(1/16) G2(1/8) P(1/16) E2(1/16) G2(1/8) P(1/16) G2(1/8) G2(1/16) E2(1/16) C3(1/16) H2(1/8) G2(1/16)

'Batman
'H2(1/16) H2(1/16) Ais2(1/16) Ais2(1/16) A2(1/16) A2(1/16) Ais2(1/16) Ais2(1/16) H2(1/16) H2(1/16) Ais2(1/16) Ais2(1/16) A2(1/16) A2(1/16) Ais2(1/16) Ais2(1/16) H2(1/8) P(1/16) H2(1/8)

'Britney Spears :: Stronger
'A1(1/2) A1(1/2) A1(1/1) H1(1/4) C2(1/4) H1(1/4) A1(1/4) G1(1/4) F1(1/2) C2(1/2) F1(1/1) E1(1/2) E1(1/1) E1(1/4) A1(1/2) A1(1/2) A1(1/1) A1(1/4) A1(1/4) H1(1/4) C2(1/4) H1(1/4) A1(1/4) G1(1/4) F1(1/2) C2(1/2) F1(1/1) E1(1/2) E1(1/1) F2(1/1) F2(1/1) E2(1/2) F2(1/4) E2(1/2) D2(1/2) D2(1/2) C2(1/1) A1(1/4) E2(1/4) D2(1/2) E2(1/2) E2(1/4) E2(1/2) G2(1/1) A1(1/2) A1(1/1) A1(1/4) C2(1/4) H2(1/1)

'Britney Spears :: Lucky
'H1(1/16) D2(1/16) E2(1/16) Fis2(1/16) H1(1/16) P(1/16) H1(1/8) H1(1/16) D2(1/16) E2(1/16) Fis2(1/16) G2(1/16) Fis2(1/16) D2(1/16) E2(1/8) P(1/8) D2(1/16) P(1/16) Fis2(1/16) H1(1/8) P(1/2) H1(1/16) D2(1/16) E2(1/16) Fis2(1/16) H1(1/16) P(1/16) H1(1/8) H1(1/16) D2(1/16) E2(1/16) Fis2(1/16) G2(1/16) Fis2(1/16) D2(1/16) E2(1/8) P(1/8) D2(1/16) P(1/16) Fis2(1/16) H1(1/8)

'Britney Spears :: Baby One More Time
'Cis1(1/8) Cis1(1/8) Cis1(1/8) Cis1(1/4) Cis1(1/8) C1(1/8) Cis1(1/8) Dis1(1/4) Gis1(1/8) Fis1(1/8) Fis1(1/8) E1(1/4) E1(1/8) E1(1/8) E1(1/8) E1(1/4) E1(1/8) Fis1(1/8) Gis1(1/8) A1(1/8) Gis1(1/4) Cis1(1/8) Cis1(1/8) Cis1(1/8) Cis1(1/8) Cis1(1/8) Cis1(1/8) C1(1/8) Cis1(1/8) Dis1(1/4) E1(1/8) Fis1(1/8) Gis1(1/8) Gis1(1/2) Fis1(1/16) E1(1/16) Fis1(1/16) E1(1/4) Gis1(1/8) A1(1/8) Gis1(1/8) A1(1/8) Gis1(1/8) A1(1/8) Gis1(1/4)

'Bomfunk MCs :: Freestyler
'G2(1/8) E2(1/8) H1(1/8) G2(1/8) E2(1/8) H1(1/8) G2(1/8) E2(1/8) H1(1/8) Fis2(1/8) E2(1/8) H1(1/8) Fis2(1/8) E2(1/8) H1(1/8) D2(1/8) C2(1/8) G1(1/8) D2(1/8) C2(1/8) G1(1/8) D2(1/8) C2(1/8) G1(1/8) E2(1/8) D2(1/8) A1(1/8) E2(1/8) D2(1/8) A1(1/8) E2(1/8) A1(1/16)

'Beatles :: Ob-la-di Ob-la-da
'Ais2(1/16) D3(1/16) F3(1/8) Ais2(1/16) D3(1/16) F3(1/8) Ais2(1/16) D3(1/16) F3(1/8) P(1/16) P(1/16) Ais3(1/8) F3(1/8) Dis3(1/16) D3(1/16) Dis3(1/16) D3(1/16) C3(1/8) Ais2(1/8)

'Beatles :: Love Me Do
'D3(1/8) D3(1/8) F3(1/16) G3(1/8) P(1/8) F3(1/8) D3(1/8) D3(1/8) F3(1/16) G3(1/8) P(1/8) F3(1/8) D3(1/8) D3(1/8) F3(1/16) G3(1/8) P(1/16) D3(1/8) E3(1/8) D3(1/8) C3(1/8) E3(1/8) P(1/8) G2(1/8) G2(1/8) Ais2(1/16) G2(1/8)

'Beatles :: Let It Be
'G2(1/16) G2(1/16) G2(1/16) A2(1/8) E2(1/16) G2(1/16) G2(1/16) C3(1/16) D3(1/16) E3(1/16) E3(1/16) E3(1/8) D3(1/16) D3(1/16) C3(1/16) C3(1/8) E3(1/16) E3(1/16) F3(1/16) E3(1/16) E3(1/8) D3(1/16) P(1/16) E3(1/16) D3(1/16) C3(1/8)

'Beatles :: Hey Jude
'G2(1/8) E2(1/8) P(1/16) E2(1/16) E2(1/16) G2(1/16) A2(1/16) D2(1/8) P(1/16) D2(1/16) E2(1/16) F2(1/8) C3(1/8) C3(1/16) C3(1/16) H2(1/16) G2(1/16) A2(1/16) G2(1/16) F2(1/16) E2(1/8) P(1/16) G2(1/16) A2(1/16) A2(1/8) A2(1/16) D3(1/16) C3(1/16) H2(1/16) H2(1/16) C3(1/16) A2(1/16) G2(1/8) P(1/16) C2(1/16) D2(1/16) E2(1/16) A2(1/16) A2(1/16) G2(1/8)

'Can-can
'C2(1/8) C2(1/8) D2(1/16) F2(1/16) E2(1/16) D2(1/16) G2(1/8) G2(1/8) G2(1/16) A2(1/16) E2(1/16) F2(1/16) D2(1/8) D2(1/8) D2(1/16) F2(1/16) E2(1/16) D2(1/16) C2(1/16) H2(1/16) A2(1/16) G2(1/16) F2(1/16) E2(1/16) D2(1/16) C2(1/16)

'Chemical Brothers
'D2(1/16) C3(1/16) P(1/16) D2(1/16) D3(1/16) P(1/16) D2(1/16) C3(1/16) P(1/16) D2(1/16) D3(1/16) P(1/16) D2(1/16) D2(1/16) F3(1/16)

'Cher :: Believe
'A2(1/16) H2(1/16) H2(1/16) P(1/16) D2(1/16) E2(1/16) D2(1/16) D2(1/16) D2(1/16) E2(1/16) D3(1/16) A2(1/16) A2(1/16) C2(1/16) C2(1/16) C2(1/16) P(1/16) P(1/16) E2(1/16) F2(1/16) G2(1/16) G2(1/16)

'Cher :: Strong Enough
'A2(1/16) H2(1/16) C3(1/8) C3(1/16) C3(1/16) P(1/8) A2(1/16) A2(1/16) E3(1/8) D3(1/16) C3(1/16) H2(1/16) C3(1/16) D3(1/16) D3(1/16) D3(1/16) P(1/8) G2(1/16) G2(1/16) F3(1/8) E3(1/16) D3(1/16) C3(1/16) D3(1/16) D3(1/16) C3(1/16) C3(1/16)

'Christina Aguilera :: Genie In A Bottle
'D2(1/8) E2(1/8) F2(1/8) E2(1/8) E2(1/8) D2(1/8) Ais1(1/4) D2(1/8) E2(1/8) F2(1/8) E2(1/8) E2(1/8) D2(1/8) A1(1/4) P(1/8) D2(1/16) E2(1/16) F2(1/8) E2(1/8) E2(1/8) D2(1/8) E2(1/8) D2(1/8) P(1/8) D2(1/16) D2(1/16) Cis2(1/8) D2(1/8) E2(1/8) D2(1/4)

'Christina Aguilera :: What A Girl Wants
'E2(1/8) E2(1/16) G2(1/8) G2(1/8) P(1/16) P(1/16) E2(1/16) E2(1/16) G2(1/8) G2(1/8) P(1/16) P(1/16) E2(1/16) E2(1/16) G2(1/8) A2(1/8) G2(1/16) E2(1/8) D2(1/16) C2(1/8) D2(1/8) E2(1/16) E2(1/8) P(1/16) C2(1/16) F2(1/8) F2(1/8) P(1/16) P(1/16) F2(1/8) Fis2(1/16) D2(1/16) C2(1/8) P(1/4)

'Classical
'C3(1/16) P(1/16) F2(1/16) G2(1/16) A2(1/16) Ais2(1/16) C3(1/8) F2(1/16) P(1/16) F2(1/16) P(1/16) D3(1/16) P(1/16) Ais2(1/16) C3(1/16) D3(1/16) E3(1/16) F3(1/8) F2(1/16) P(1/16) F2(1/16) P(1/16) Ais2(1/8) C3(1/16) Ais2(1/16) A2(1/16) G2(1/16) A2(1/8) Ais2(1/16) A2(1/16) G2(1/16) F2(1/16) G2(1/8) A2(1/16) G2(1/16) F2(1/16) E2(1/16) F2(1/8)

'Coca-Cola
'E2(1/8) E2(1/16) E2(1/16) F2(1/16) F2(1/8) P(1/8) D2(1/8) D2(1/8) D2(1/16) E2(1/16) E2(1/8) P(1/8) E2(1/8) E2(1/8) E2(1/16) F2(1/16) F2(1/16) P(1/16) E2(1/16) D2(1/16) P(1/16) D2(1/16) G2(1/16) E2(1/8) C2(1/8)

'Cool effect
'F2(1/8) C2(1/16) C2(1/16) D2(1/8) C2(1/8) G2(1/8) D2(1/16) D2(1/16) E2(1/8) D2(1/8) A2(1/8) E2(1/16) E2(1/16) Fis2(1/8) E2(1/8) H2(1/8) Fis2(1/16) Fis2(1/16) Gis2(1/8) Fis2(1/8) C3(1/8) G2(1/16) G2(1/16) A2(1/8) G2(1/8) P(1/8) H2(1/8) C3(1/8)

'Coolio :: C U When U Get There
'G2(1/8) F2(1/8) G2(1/8) Ais2(1/8) Gis2(1/8) G2(1/8) Gis2(1/16) P(1/16) P(1/16) P(1/16) Ais2(1/8) Gis2(1/8) Ais2(1/16) P(1/16) P(1/16) P(1/16) Gis2(1/8) G2(1/8) Gis2(1/16) P(1/16) P(1/16) P(1/16) G2(1/8) F2(1/8) G2(1/8) Ais2(1/8) Gis2(1/8) G2(1/8) Gis2(1/16) P(1/16) P(1/16) P(1/16) Ais2(1/8) Gis2(1/8) Ais2(1/8) Gis2(1/8) G2(1/8) F2(1/8) G2(1/8)

'Corona :: Rythm of The Night
'C2(1/16) P(1/16) F2(1/16) P(1/16) G2(1/16) P(1/16) F2(1/16) Ais2(1/16) P(1/16) A2(1/16) P(1/16) G2(1/16) P(1/16) A2(1/16) F2(1/16) P(1/16)

'Depeche Mode :: Strange Love
'E2(1/16) G2(1/16) E2(1/16) A2(1/8) G2(1/16) E2(1/16) P(1/16) E2(1/16) G2(1/16) E2(1/16) A2(1/16) A2(1/16) G2(1/16) E2(1/16) P(1/16) E2(1/16) G2(1/16) E2(1/16) A2(1/8) G2(1/16) E2(1/16) P(1/16) E2(1/16) G2(1/16) E2(1/16) D3(1/16) D3(1/16) H2(1/16) G2(1/16)

'Dio :: Holy Diver
'E2(1/8) E2(1/16) E2(1/16) E2(1/8) E2(1/16) E2(1/16) E2(1/8) Fis2(1/8) G2(1/8) P(1/8) E2(1/8) E2(1/16) E2(1/16) E2(1/8) E2(1/16) E2(1/16) G2(1/8) G2(1/8) D2(1/8) D2(1/8)

'Dana International :: Diva
'C3(1/16) H2(1/16) C3(1/16) H2(1/8) A2(1/8) P(1/16) C3(1/16) H2(1/16) C3(1/16) H2(1/8) A2(1/8) P(1/16) H2(1/16) P(1/16) A2(1/16) Gis2(1/8) H2(1/16) P(1/16) H2(1/8) P(1/16) D3(1/16) C3(1/16) D3(1/16) C3(1/8) H2(1/8) D3(1/16) C3(1/16) D3(1/16) C3(1/8) H2(1/8) C3(1/16) P(1/16) H2(1/16) A2(1/8) C3(1/8) H2(1/8)

'Dallas
'C2(1/16) F2(1/8) P(1/16) C2(1/16) C3(1/8) P(1/16) F2(1/16) A2(1/8) G2(1/16) A2(1/16) F2(1/8) C2(1/8)

'Eagles :: Hotel California
'H2(1/8) Ais2(1/16) H2(1/8) A2(1/16) A2(1/16) A2(1/8) H2(1/8) P(1/16) H2(1/16) Ais2(1/16) H2(1/8) A2(1/8) A2(1/8) A2(1/8) P(1/16) A2(1/16) A2(1/16) H2(1/16) H2(1/16) A2(1/16) A2(1/16) A2(1/16) A2(1/16) H2(1/16) P(1/16) H2(1/8) H2(1/8) H2(1/8) A2(1/8) A2(1/8) A2(1/16) G2(1/16) E2(1/8)

'Effiel 65: Too much of heaven
'Cis2(1/16) E2(1/16) Cis2(1/16) Fis2(1/16) E2(1/16) Fis2(1/8) H2(1/16) Fis2(1/16) Fis2(1/16) Fis2(1/16) E2(1/16) A2(1/8) E2(1/16) Fis2(1/16) E2(1/16) Gis2(1/16) A2(1/16) Gis2(1/16) Fis2(1/16) E2(1/16) Cis2(1/16) E2(1/16) Cis2(1/16) Fis2(1/16) E2(1/16) Fis2(1/8) H2(1/16) Fis2(1/16) Fis2(1/16) Fis2(1/16) E2(1/16) A2(1/8) E2(1/16) Fis2(1/16) Gis2(1/16) Gis2(1/16) A2(1/16) Gis2(1/16) Fis2(1/16) E2(1/16)

'Elton John :: Candle In The Wind
'Gis2(1/16) Gis2(1/8) Gis2(1/8) E2(1/16) Gis2(1/8) P(1/16) P(1/16) E2(1/16) E2(1/16) Fis2(1/16) Gis2(1/16) E2(1/16) P(1/16) P(1/16) Cis3(1/8) Cis3(1/8) D3(1/16) Cis3(1/8) H2(1/16) H2(1/16) H2(1/16) Cis3(1/8) H2(1/8) H2(1/8) E2(1/16) E2(1/8) P(1/16) Fis2(1/16) Gis2(1/16) A2(1/8) Gis2(1/8) Fis2(1/16) E2(1/8) Cis2(1/8)

'Elvis :: Love Me Tender
'D2(1/8) G2(1/8) Fis2(1/8) G2(1/8) A2(1/8) E2(1/8) A2(1/8) P(1/16) P(1/16) G2(1/8) Fis2(1/8) E2(1/8) Fis2(1/8) G2(1/8)

'Emilia :: Big Big World
'C2(1/8) D2(1/8) E2(1/8) P(1/8) E2(1/8) P(1/8) E2(1/8) P(1/8) E2(1/8) F2(1/8) D2(1/8) P(1/8) D2(1/8) P(1/8) D2(1/8) P(1/8) D2(1/16) D2(1/8) E2(1/8) C2(1/8) P(1/8) C2(1/8) P(1/8) C2(1/8) P(1/8) C2(1/8) D2(1/8) E2(1/2) D2(1/8)

'Eminem :: Stan
'Gis1(1/16) Dis2(1/16) Dis2(1/16) Dis2(1/16) E2(1/16) Cis2(1/16) H1(1/16) Dis2(1/32) H1(1/16) Cis2(1/8) Ais1(1/16) H1(1/16) Dis2(1/16) Ais1(1/16) Dis2(1/16) Gis1(1/8) Gis1(1/16) Dis2(1/16) Dis2(1/16) Dis2(1/16) E2(1/16) Cis2(1/16) H1(1/8) Dis2(1/8) Cis2(1/4) H1(1/16) Fis2(1/16) Gis2(1/16) Dis2(1/16) Cis2(1/16) Dis2(1/8)

'Eminem: Way I Am
'A1(1/2) H1(1/2) H1(1/4) D2(1/8) C2(1/8) A1(1/2) C2(1/2) A1(1/2) GIS1(1/4) E1(1/4) A1(1/2)

'Eric Clapton :: Layla
'A2(1/16) C3(1/16) D3(1/16) F3(1/16) D3(1/16) C3(1/16) D3(1/8) P(1/4) G3(1/8) P(1/8) F3(1/8) P(1/8) E3(1/8) P(1/8) C3(1/8) P(1/8) D3(1/8) P(1/8) A2(1/16) C3(1/16) D3(1/16) F3(1/16) D3(1/16) C3(1/16) D3(1/8)

'Europe :: Final Countdown
'H2(1/16) A2(1/16) H2(1/8) P(1/16) E2(1/8) P(1/8) P(1/16) C3(1/16) H2(1/16) C3(1/16) P(1/16) H2(1/16) P(1/16) A2(1/8) P(1/16) P(1/8) C3(1/16) H2(1/16) C3(1/8) P(1/16) E2(1/8) P(1/8) P(1/16) A2(1/16) G2(1/16) A2(1/16) P(1/16) G2(1/16) P(1/16) Fis2(1/16) P(1/16) A2(1/16) P(1/16) G2(1/8)

'Eurovision Song Contest Tune
'D2(1/8) G2(1/8) G2(1/16) A2(1/16) H2(1/8) G2(1/8) D3(1/8) D3(1/8) H2(1/8) H2(1/16) C3(1/8) D3(1/16) C3(1/16) H2(1/16) C3(1/16) D3(1/8) A2(1/16) G2(1/16) A2(1/16) H2(1/16) A2(1/8) D2(1/8) G2(1/8) G2(1/16) A2(1/16) H2(1/8) G2(1/8) D3(1/8) D3(1/8) H2(1/8) H2(1/16) C3(1/16) D3(1/16) H2(1/16) C3(1/16) A2(1/8) G2(1/16) G2(1/8)

'Exorcist
'E2(1/16) A2(1/16) E2(1/16) H2(1/16) E2(1/16) G2(1/16) A2(1/16) E2(1/16) C3(1/16) E2(1/16) D3(1/16) E2(1/16) H2(1/16) C3(1/16) E2(1/16) H2(1/16) E2(1/16) A2(1/16) E2(1/16) H2(1/16) E2(1/16) G2(1/16) A2(1/16) E2(1/16) C3(1/16) E2(1/16) D3(1/16) E2(1/16) H2(1/16) C3(1/16) E2(1/16) H2(1/16) E2(1/16) A2(1/16) E2(1/16) H2(1/16) E2(1/16) G2(1/16) A2(1/8)

'Eye of the Tiger
'A2(1/8) C3(1/16) A2(1/8) P(1/16) G2(1/16) F2(1/16) A2(1/16) G2(1/8) F2(1/16) P(1/16) G2(1/16) G2(1/16) G2(1/8) G2(1/16) A2(1/16) G2(1/16) F2(1/8)

'Fools Garden :: Lemon Tree
'H2(1/8) P(1/8) H2(1/16) C3(1/16) D3(1/16) P(1/16) C3(1/16) P(1/16) H2(1/16) E3(1/16) P(1/16) H2(1/8) P(1/8) H2(1/16) C3(1/16) D3(1/16) P(1/16) C3(1/16) P(1/16) E3(1/16) H2(1/16) P(1/16) A2(1/8) P(1/8) H2(1/16) P(1/16) A2(1/16) G2(1/16) E2(1/16) E2(1/8)

'Foreigner :: I Want To Know What Love Is
'E3(1/16) E3(1/16) E3(1/16) E3(1/8) C3(1/16) E3(1/8) D3(1/8) P(1/8) A2(1/8) F3(1/8) P(1/16) E3(1/16) E3(1/16) E3(1/16) E3(1/8) C3(1/16) C3(1/8) D3(1/8) P(1/16) A2(1/16) F3(1/8) E3(1/16) E3(1/16) E3(1/16) D3(1/16) D3(1/8) E3(1/16) E3(1/16) E3(1/8) D3(1/8)

'Four Weddings and a Funeral
'E3(1/8) E3(1/8) D3(1/8) C3(1/8) D3(1/8) A2(1/8) P(1/8) F3(1/8) F3(1/8) E3(1/8) D3(1/8) D3(1/8) P(1/8) E3(1/8)

'Fugees :: Killing Me Softly
'C3(1/8) C3(1/8) C3(1/8) C3(1/8) C3(1/8) A2(1/8) E2(1/8) G2(1/8) G2(1/8) F2(1/8) F2(1/8) P(1/16) H2(1/8) H2(1/8) H2(1/8) H2(1/8) H2(1/8) G2(1/8) D2(1/8) E2(1/8) P(1/16) E2(1/8) E2(1/8) E2(1/8) E2(1/8) E2(1/8) A2(1/8) C3(1/8) H2(1/8) H2(1/8) A2(1/8) D3(1/8) D3(1/8) A2(1/8) C3(1/8) C3(1/8) H2(1/8) H2(1/8)

'George Michael :: Fast Love
'A2(1/8) P(1/8) A2(1/8) G2(1/8) A2(1/8) P(1/8) E3(1/8) P(1/8) D3(1/8) P(1/2) P(1/8) C3(1/8) H2(1/8) C3(1/8) H2(1/8) C3(1/8) H2(1/8) P(1/8) G2(1/8) P(1/8) A2(1/8) P(1/8) H2(1/8) G2(1/8)

'Ghostbusters
'H2(1/16) H2(1/16) Dis3(1/8) H2(1/16) P(1/16) Cis3(1/8) A2(1/16) P(1/2) P(1/16) H2(1/16) H2(1/16) H2(1/16) H2(1/16) A2(1/8) H2(1/16)

'Godfather
'E2(1/8) A2(1/8) C3(1/8) H2(1/8) A2(1/8) C3(1/8) A2(1/8) H2(1/8) A2(1/8) F2(1/8) G2(1/8) E2(1/8) P(1/4) P(1/16) E2(1/8) A2(1/8) C3(1/8) H2(1/8) A2(1/8) C3(1/8) A2(1/8) H2(1/8) A2(1/8) E2(1/8) Dis2(1/8) D2(1/8)

'Haddaway :: What Is Love
'C3(1/16) H2(1/16) C3(1/16) A2(1/16) C3(1/16) H2(1/16) C3(1/16) A2(1/16) C3(1/16) H2(1/16) C3(1/16) G2(1/16) C3(1/16) H2(1/16) C3(1/16) G2(1/16) H2(1/16) A2(1/16) H2(1/16) G2(1/16) H2(1/16) A2(1/16) H2(1/16) G2(1/16) H2(1/16) A2(1/16) H2(1/16) G2(1/16) H2(1/16) A2(1/16) H2(1/16) G2(1/16)

'Happy Birthday
'C2(1/16) C2(1/16) D2(1/8) C2(1/8) F2(1/8) E2(1/8) P(1/8) C2(1/16) C2(1/16) D2(1/8) C2(1/8) G2(1/8) F2(1/8) P(1/8) C2(1/16) C2(1/16) C3(1/8) A2(1/8) F2(1/8) E2(1/8) D2(1/8) P(1/16) Ais2(1/16) Ais2(1/16) A2(1/8) F2(1/8) G2(1/8) F2(1/8)

'Hymn of the USSR
'G2(1/8) P(1/16) C3(1/8) P(1/16) G2(1/8) A2(1/16) H2(1/8) P(1/16) E2(1/8) E2(1/16) A2(1/8) P(1/16) G2(1/8) F2(1/16) G2(1/8) P(1/16) C2(1/8) C2(1/16) D2(1/8) P(1/16) D2(1/8) E2(1/16) F2(1/8) P(1/16) F2(1/8) G2(1/16) A2(1/8) P(1/16) H2(1/8) C3(1/16) D3(1/8) P(1/8)

'Indiana Jones :: Raiders March
'E2(1/8) E2(1/16) F2(1/16) G2(1/8) C3(1/2) D2(1/8) D2(1/16) E2(1/16) F2(1/2) G2(1/8) G2(1/16) A2(1/16) H2(1/8) F3(1/2) A2(1/4) H2(1/16) C3(1/4) D3(1/4) E3(1/4)

'James Bond :: License To Kill
'E2(1/16) Fis2(1/16) Gis2(1/8) Fis2(1/8) E2(1/8) Gis2(1/8) P(1/4) P(1/8) Fis2(1/16) Gis2(1/16) A2(1/8) Gis2(1/8) Fis2(1/8) E2(1/8) Fis2(1/8) E2(1/8) H2(1/8) Gis2(1/8)

'Jean Michel Jarre :: Oxygene 10
'C3(1/16) C2(1/16) Fis2(1/16) C2(1/16) C3(1/16) C2(1/16) Fis2(1/16) C2(1/16) Ais2(1/16) C2(1/16) Fis2(1/16) C2(1/16) Gis2(1/16) C2(1/16) Fis2(1/16) C2(1/16) G2(1/16) C2(1/16) Fis2(1/16) C2(1/16) G2(1/16) C2(1/16) Fis2(1/16) C2(1/16) G2(1/16) C2(1/16) Fis2(1/16) C2(1/16) G2(1/16) C2(1/16) Fis2(1/16) C2(1/16)

'Kalinka
'G2(1/16) F2(1/8) D2(1/16) E2(1/16) F2(1/8) D2(1/16) E2(1/16) F2(1/8) E2(1/16) D2(1/16) C2(1/8) G2(1/16) G2(1/16) F2(1/16) F2(1/16) D2(1/16) E2(1/16) F2(1/8) D2(1/16) E2(1/16) F2(1/8) E2(1/16) D2(1/16) C2(1/8)

'Kylie Minogue :: Spinning Around
'D2(1/4) P(1/4) D2(1/8) E2(1/8) F2(1/8) E2(1/8) P(1/4) D2(1/8) E2(1/8) F2(1/8) G2(1/8) F2(1/8) P(1/4) D2(1/8) F2(1/8) D2(1/8) A2(1/8) P(1/8) G2(1/8) G2(1/8) F2(1/8) G2(1/8) F2(1/8) G2(1/8) D2(1/8) D2(1/4) P(1/4) D2(1/8) E2(1/8) F2(1/8) E2(1/8) P(1/4) D2(1/8) E2(1/8) F2(1/8) G2(1/8) F2(1/8) P(1/4) D2(1/8) F2(1/8) D2(1/8) A2(1/8) P(1/8) G2(1/8) G2(1/8) F2(1/8) G2(1/8) F2(1/8) G2(1/8) D2(1/8)

'Led Zeppelin :: Stairway to heaven
'A2(1/8) C2(1/8) E2(1/8) A2(1/8) H2(1/8) C2(1/8) E2(1/8) H2(1/8) C3(1/8) C2(1/8) E2(1/8) C3(1/8) A2(1/8) A2(1/8) P(1/4) E2(1/8) F2(1/8) F2(1/8) P(1/4) H2(1/8) C3(1/8) H2(1/8) G2(1/8) A2(1/8) A2(1/8)

'Love story
'C3(1/8) E2(1/8) E2(1/8) C3(1/8) C3(1/8) P(1/16) E2(1/8) E2(1/8) C3(1/8) C3(1/8) E2(1/8) F2(1/8) E2(1/8) D2(1/8) D2(1/8) D2(1/8) H2(1/8) H2(1/8) P(1/16) D2(1/8) D2(1/8) H2(1/8) H2(1/8) D2(1/8) E2(1/8) D2(1/8) C2(1/8) C2(1/8) C2(1/8) A2(1/8) A2(1/8)

'Macarena
'C3(1/16) P(1/16) C3(1/16) C3(1/16) C3(1/16) P(1/16) C3(1/16) C3(1/16) C3(1/16) C3(1/16) C3(1/16) C3(1/16) C3(1/16) E3(1/16) P(1/16) A2(1/16) G2(1/16) C3(1/16) P(1/16) C3(1/16) C3(1/16) C3(1/16) P(1/16) C3(1/16) C3(1/16) C3(1/16) C3(1/16) C3(1/16) C3(1/16) A2(1/16) G2(1/16)

'Michael Jackson: Billy Jean
'Fis3(1/8) Cis3(1/8) E3(1/8) Fis3(1/16) E3(1/8) Cis3(1/8) H2(1/8) Cis3(1/8)

'Michael Jackson: Beat It
'E2(1/8) G2(1/16) H2(1/16) G3(1/16) E3(1/16) P(1/16) E3(1/16) Fis3(1/8) E3(1/16) D3(1/16) P(1/16) D3(1/8) P(1/16) E2(1/8) G2(1/16) H2(1/16) G3(1/16) E3(1/16) P(1/16) E3(1/16) Fis3(1/8) E3(1/16) D3(1/16)

'Mission Impossible
'D2(1/8) P(1/16) D2(1/16) P(1/16) D2(1/16) F2(1/16) P(1/16) G2(1/16) P(1/16) D2(1/8) P(1/16) D2(1/16) P(1/16) D2(1/16) C2(1/16) P(1/16) Cis2(1/16) D2(1/8) P(1/16) D2(1/16) P(1/16) D2(1/16) F2(1/16) P(1/16) G2(1/16) P(1/16) D2(1/8) P(1/16) D2(1/16) P(1/16) D2(1/16) C2(1/16) P(1/16) Cis2(1/16)

'Movetron: Romeo & Julia, chorus
'G2(1/16) F2(1/16) Fis2(1/16) F2(1/8) G2(1/16) Dis2(1/8) G2(1/16) F2(1/16) Fis2(1/16) F2(1/8) G2(1/16) Dis2(1/8) Fis2(1/16) F2(1/8) F2(1/8) F2(1/8) F2(1/8) G2(1/16) Gis2(1/16) G2(1/8) Gis2(1/16) G2(1/8) G2(1/16) F2(1/16) Fis2(1/16) F2(1/8) G2(1/16) Dis2(1/8) G2(1/16) F2(1/16) Fis2(1/16) F2(1/8) G2(1/16) Dis2(1/8) Fis2(1/16) F2(1/8) F2(1/8) F2(1/8) F2(1/8) G2(1/16) Gis2(1/16) G2(1/8) Gis2(1/16) G2(1/8) Gis2(1/16) G2(1/8)

'National Anthem Of USA
'C3(1/8) A2(1/16) F2(1/8) P(1/16) A2(1/8) P(1/16) C3(1/8) P(1/16) F3(1/8) P(1/16) A3(1/8) G3(1/16) F3(1/8) P(1/16) A2(1/8) P(1/16) H2(1/8) P(1/16) C3(1/8) P(1/16) C3(1/8) C3(1/16) A3(1/8) P(1/16) G3(1/8) P(1/16) F3(1/8) P(1/16) E3(1/8) P(1/16) D3(1/8) E3(1/16) F3(1/8) P(1/16) F3(1/8) P(1/16) C3(1/8) P(1/16) A2(1/8) F2(1/8)

'NBA
'F2(1/16) P(1/16) C2(1/16) P(1/16) D2(1/16) P(1/16) E2(1/16) P(1/16) F2(1/16) P(1/16) C2(1/16) P(1/16) D2(1/16) P(1/16) E2(1/16) P(1/16) F2(1/16) P(1/16) C2(1/16) P(1/16) D2(1/16) P(1/16) E2(1/16) P(1/16) Fis2(1/8) P(1/8) G2(1/16) C3(1/16) E3(1/16) G3(1/16) E3(1/16) G3(1/8) P(1/16) Gis2(1/16) Cis3(1/16) F3(1/16) Gis3(1/16) F3(1/16) Gis3(1/8)

'No Doubt: Don't Speak
'F2(1/8) Gis2(1/8) P(1/4) P(1/8) P(1/16) Gis2(1/16) Cis2(1/8) F2(1/8) G2(1/8) F2(1/16) Gis2(1/8) G2(1/8) P(1/4) C2(1/8) E2(1/8) G2(1/8) Gis2(1/16) G2(1/8) F2(1/8) P(1/8) P(1/16) C2(1/16) C2(1/8) E2(1/8) G2(1/8) E2(1/16) F2(1/8)

'Nokia Ring
'G3(1/16) F3(1/16) A2(1/8) H2(1/8) E3(1/16) D3(1/16) F2(1/8) G2(1/8) D3(1/16) C3(1/16) E2(1/8) G2(1/8) C3(1/8)

'Olle
'A2(1/16) D2(1/16) A2(1/16) E2(1/16) A2(1/16) E2(1/16) D2(1/16) E2(1/16) A2(1/16) E2(1/16) D2(1/16) E2(1/16) A2(1/16) D2(1/16) E2(1/16) A2(1/16) D2(1/16) E2(1/16) E2(1/16)

'Offspring: Why don't you get a job
'H3(1/8) H3(1/8) P(1/16) P(1/16) A3(1/8) G3(1/8) A3(1/8) H3(1/8) A3(1/8) G3(1/8) A3(1/8) G3(1/8) P(1/8) G3(1/8) P(1/4) P(1/16) H3(1/8) H3(1/8) P(1/16) P(1/16) G3(1/8) P(1/8) A3(1/8) H3(1/8) G3(1/8) A3(1/8) P(1/8)

'O-Sole-Mio
'C3(1/8) C3(1/8) H2(1/8) G2(1/8) G2(1/4) H2(1/8) H2(1/8) A2(1/8) F2(1/4) H2(1/8) H2(1/8) A2(1/8) F2(1/8) F2(1/4) D2(1/8) E2(1/8) F2(1/8) G2(1/4) G2(1/8) Gis2(1/8) G2(1/4) F2(1/8) C3(1/8) Gis2(1/8) G2(1/4) E2(1/8) D2(1/8) C2(1/8) G2(1/8) G2(1/4) E2(1/8) D2(1/8) C2(1/8) C2(1/4)

'Police: Message In A Bottle
'E3(1/16) Gis2(1/16) Dis3(1/16) Cis3(1/8) E2(1/16) H2(1/16) Dis3(1/8) Fis2(1/16) H2(1/16) Cis3(1/8) Cis2(1/16) Gis2(1/16) Cis3(1/16) E3(1/16) Gis2(1/16) Dis3(1/16) Cis3(1/8) E2(1/16) H2(1/16) Dis3(1/8) Fis2(1/16) H2(1/16) Cis3(1/8) Cis2(1/16) Gis2(1/16) Cis3(1/16)
'C3(1/16) Ais2(1/16) C3(1/16) G2(1/16) Fis2(1/16) G2(1/16) C2(1/16) P(1/16) C3(1/16) Ais2(1/16) C3(1/16) G2(1/16) Fis2(1/16) G2(1/16) C2(1/16) P(1/16) C3(1/16) D3(1/16) Dis3(1/16) D3(1/16) Dis3(1/16) C3(1/16) D3(1/16) C3(1/16) D3(1/16) Ais2(1/16) C3(1/16) Ais2(1/16) C3(1/

'Prodigy: Breathe
'D2(1/16) D2(1/16) D2(1/16) D2(1/16) F2(1/16) D2(1/16) F2(1/16) E2(1/16) D2(1/16) E2(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16) D2(1/16) D2(1/16) D2(1/16) D2(1/16) F2(1/16) D2(1/16) F2(1/16) E2(1/16) D2(1/16) E2(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16)

'Puff Daddy: I'll Be Missing You v2.0
'E2(1/8) F2(1/8) E2(1/8) P(1/16) D2(1/8) P(1/16) C2(1/8) P(1/8) P(1/16) E2(1/8) F2(1/8) E2(1/8) P(1/16) D2(1/8) P(1/16) E2(1/8) P(1/8) C2(1/8) C2(1/8) E2(1/8) F2(1/8) P(1/16) F2(1/8) P(1/8) C2(1/8) C2(1/8) F2(1/8) E2(1/8) P(1/16) D2(1/8) P(1/16) D2(1/8) C2(1/8) E2(1/8) D2(1/8) P(1/16) C2(1/8)
'1/16) P(1/16)

'Queen: We Are The Champions
'Gis2(1/8) P(1/4) P(1/8) G2(1/8) Gis2(1/8) G2(1/8) P(1/8) Dis2(1/8) P(1/4) C2(1/8) F2(1/8)

'Real2real: I Like To Move It
'C2(1/16) P(1/16) C2(1/16) P(1/16) C2(1/16) P(1/16) C2(1/16) G2(1/16) Fis2(1/16) P(1/16) Fis2(1/16) E2(1/16) D2(1/16) F2(1/16) D2(1/16) G2(1/16) C2(1/16) P(1/16) C2(1/16) P(1/16) C2(1/16) P(1/16) C2(1/16) G2(1/16) Fis2(1/16) P(1/16) Fis2(1/16) E2(1/16) D2(1/16) F2(1/16) D2(1/16) G2(1/16) C2(1/16)

'Red Hot Chili Peppers: Higher Ground
'C2(1/8) C2(1/16) C3(1/8) C2(1/16) Fis2(1/16) Fis2(1/16) Dis3(1/16) F2(1/16) F2(1/16) F3(1/16) C2(1/8) C2(1/16) C3(1/8) C2(1/16) Fis2(1/16) Fis2(1/16) Dis3(1/16) F2(1/16) F2(1/16) F3(1/16)

'Red Hot Chili Peppers: I Could Have Lied
'D2(1/8) E2(1/8) G2(1/8) E2(1/8) H2(1/8) P(1/8) E2(1/8) G2(1/8) E2(1/8) H2(1/8) P(1/8) E2(1/8) G2(1/8) E2(1/8) H2(1/8) P(1/8) D3(1/8) P(1/4) C3(1/8) P(1/16) P(1/8) P(1/16) H2(1/8) P(1/4) G2(1/8)

'Red Hot Chili Peppers: My Friends
'E2(1/8) H2(1/8) Fis3(1/8) E2(1/8) G2(1/8) A2(1/16) H2(1/16) Fis3(1/8) G2(1/8) Cis2(1/8) E2(1/8) A2(1/8) Cis2(1/8) D2(1/8) E2(1/16) Fis2(1/16) H2(1/16) A2(1/16) Fis2(1/16) A2(1/16) E2(1/8) H2(1/8) Fis3(1/8)

' Shiny Happy People
'G2(1/16) F2(1/16) G2(1/16) P(1/16) F2(1/16) P(1/16) C2(1/8) P(1/8) C2(1/16) C2(1/16) D2(1/8) F2(1/8) F2(1/8) C2(1/8) G2(1/8) P(1/16) P(1/16) F2(1/8) P(1/4) G2(1/16) F2(1/16) G2(1/16) P(1/16) F2(1/16) P(1/16) C2(1/8) P(1/8) C2(1/16) C2(1/16) D2(1/8) P(1/8) F2(1/8)

'Ricky Martin: Livin' La Vida Loca
'E3(1/16) P(1/16) E3(1/8) P(1/16) H2(1/16) C3(1/16) D3(1/16) P(1/16) F3(1/16) P(1/16) E3(1/8) P(1/8) E3(1/16) P(1/16) E3(1/8) P(1/16) H2(1/16) H2(1/16) D3(1/16) P(1/16) C3(1/16) P(1/16) A2(1/8)

'Robbie Williams: Millennium
'Ais2(1/8) A2(1/16) Ais2(1/16) A2(1/8) G2(1/16) A2(1/16) G2(1/8) G2(1/8) F2(1/8) P(1/8) Gis2(1/8) G2(1/16) Gis2(1/16) G2(1/8) F2(1/16) G2(1/16) F2(1/8) F2(1/8) Dis2(1/8)

'Robbie Williams: Supreme
'Dis3(1/8) Dis3(1/8) C3(1/16) D3(1/8) C3(1/16) Ais2(1/4) Dis3(1/8) F3(1/4) Fis3(1/2) Fis3(1/8) F3(1/4) Dis3(1/2) Dis3(1/8) Ais2(1/8) Gis2(1/8) Ais2(1/2) Gis2(1/8) Ais2(1/8) Ais2(1/8) Gis2(1/8) Ais2(1/4)

'Robert Miles: Fable
'C3(1/16) D3(1/16) E3(1/8) D3(1/16) E3(1/8) C3(1/8) P(1/16) D3(1/8) C3(1/16) D3(1/8) H2(1/8) P(1/16) C3(1/8) H2(1/16) C3(1/8) A2(1/8) P(1/4) A2(1/16) H2(1/16) C3(1/16) E3(1/16) A2(1/8) P(1/8) A2(1/16) H2(1/16) C3(1/16) E3(1/8) P(1/8) A2(1/16) H2(1/16) C3(1/16) G3(1/8)

'Robert Miles: One
'Ais2(1/16) P(1/4) C2(1/16) Ais2(1/16) Gis2(1/16) P(1/4) C2(1/16) Gis2(1/16) G2(1/16) P(1/4) C2(1/16) G2(1/16) F2(1/16) P(1/8) P(1/16) C2(1/16) F2(1/16) G2(1/16) Gis2(1/16) F2(1/16) Ais2(1/16)

'Rolling Stones: Satisfaction
'D2(1/16) P(1/16) D2(1/8) P(1/16) D2(1/16) E2(1/16) F2(1/8) P(1/16) F2(1/16) F2(1/8) E2(1/8) D2(1/16) P(1/16) D2(1/8) P(1/16) D2(1/16) E2(1/16) F2(1/8) P(1/16) F2(1/16) F2(1/8) E2(1/8)

'Roxette: How Do You Do?
'H2(1/16) A2(1/16) H2(1/16) A2(1/16) H2(1/16) A2(1/16) G2(1/8) G2(1/16) F2(1/16) H2(1/16) E2(1/8) P(1/8) H2(1/16) E2(1/16) F2(1/8) F2(1/16) F2(1/8) H2(1/16) A2(1/16) H2(1/16) A2(1/16) H2(1/16) A2(1/16) G2(1/8) G2(1/16) G2(1/16) G2(1/16) F2(1/16) H2(1/16) E2(1/8) F2(1/8) F2(1/16) F2(1/8)

'Roxette: Joyride
'C3(1/16) C3(1/8) P(1/16) C2(1/16) Ais2(1/8) P(1/16) Ais2(1/16) A2(1/16) G2(1/8) P(1/16) C2(1/16) C2(1/16) C2(1/16) C2(1/16) D2(1/16) D2(1/16) E2(1/8) E2(1/8)

'Roxette: Listen To Your Heart
'D2(1/8) D2(1/8) F2(1/8) C3(1/8) P(1/8) Ais2(1/8) P(1/8) A2(1/8) G2(1/8) G2(1/8) F2(1/8) A2(1/8) P(1/4) E2(1/16) F2(1/16) C3(1/16) A2(1/16) G2(1/16) F2(1/16) D2(1/8) D2(1/8) P(1/8) C2(1/16) D2(1/16) E2(1/8) E2(1/8) G2(1/8) F2(1/8)

'Run DMC: Walk This Way
'F2(1/16) Fis2(1/16) G2(1/16) C3(1/8) F2(1/16) Fis2(1/16) G2(1/16) C3(1/8) C2(1/16) P(1/4) P(1/16) F2(1/16) Fis2(1/16) G2(1/16) C3(1/8) F2(1/16) Fis2(1/16) G2(1/16) C3(1/8) C2(1/8) C3(1/8)

'Russians
'G2(1/8) C3(1/8) G3(1/8) G3(1/8) F3(1/16) Dis3(1/16) Dis3(1/8) D3(1/16) C3(1/16) P(1/8) C3(1/16) C3(1/16) C3(1/8) D3(1/8) Dis3(1/16) F3(1/16) G3(1/16) Gis3(1/16) G3(1/8) F3(1/16) F3(1/16) P(1/8) H2(1/16) H2(1/16) C3(1/16) G3(1/16) G3(1/16) G3(1/16) G3(1/8) Gis3(1/16) Ais3(1/16) Ais3(1/8) Ais3(1/16) G3(1/16)

'Saku Sammakko
'G2(1/16) G2(1/16) G2(1/8) G2(1/16) G2(1/16) G2(1/16) G2(1/16) G2(1/16) P(1/16) H2(1/8) G2(1/8) E2(1/8) G2(1/8) G2(1/8) P(1/8) P(1/16) G2(1/8) G2(1/8) P(1/8) H2(1/16) H2(1/16) H2(1/8) D3(1/16) D3(1/16) D3(1/16) D3(1/16) D3(1/8) E3(1/8) D3(1/8) H2(1/8) D3(1/8) D3(1/8) P(1/8) P(1/16) D3(1/8) D3(1/8)

'Sash: Ecquador
'H2(1/16) P(1/16) Fis2(1/8) D3(1/16) Cis3(1/16) E3(1/16) Cis3(1/16) A2(1/16) H2(1/16) P(1/16) Fis2(1/8) D3(1/16) Cis3(1/16) E3(1/16) Cis3(1/16) A2(1/16) D3(1/16) P(1/16) A2(1/8) Fis3(1/16) E3(1/16) Fis3(1/16) E3(1/16) Cis3(1/16) D3(1/16) P(1/16) H2(1/8) D3(1/16) Cis3(1/16) D3(1/16) Cis3(1/16) A2(1/16)

'Sash: Mysterious Times
'Cis2(1/16) E2(1/16) P(1/16) E2(1/16) P(1/16) E2(1/16) P(1/16) E2(1/16) Fis2(1/16) H2(1/16) P(1/16) H2(1/16) P(1/16) H2(1/16) Fis2(1/16) E2(1/16) Cis2(1/16) E2(1/16) P(1/16) E2(1/16) P(1/16) E2(1/16) P(1/16) E2(1/16) Fis2(1/16) H2(1/16) P(1/16) H2(1/16)

'Scarface
'E2(1/8) A2(1/8) C3(1/8) H2(1/8) A2(1/8) C3(1/8) A2(1/8) H2(1/8) A2(1/8) F2(1/8) G2(1/8) E2(1/8) P(1/4) P(1/16) E2(1/8) A2(1/8) C3(1/8) H2(1/8) A2(1/8) C3(1/8) A2(1/8) H2(1/8) A2(1/8) E2(1/8) Dis2(1/8) D2(1/8)

'Scooter: Back In The UK
'F2(1/16) A2(1/16) C3(1/16) F2(1/16) A2(1/16) C3(1/16) F2(1/16) A2(1/16) G2(1/16) H2(1/16) D3(1/16) G2(1/16) H2(1/16) D3(1/16) G2(1/16) H2(1/16) A2(1/16) P(1/16) A2(1/16) P(1/16) A2(1/8) P(1/16) A2(1/16) P(1/16) A2(1/16) P(1/16) A2(1/16) A2(1/16) P(1/16) A2(1/16)

'Scooter: No Fate
'G3(1/16) H2(1/16) G3(1/16) H2(1/16) Fis3(1/16) H2(1/16) Fis3(1/16) H2(1/16) E3(1/16) H2(1/16) E3(1/16) H2(1/16) D3(1/16) H2(1/16) D3(1/16) H2(1/16) E3(1/16) G2(1/16) E3(1/16) G2(1/16) D3(1/16) G2(1/16) D3(1/16) G2(1/16) C3(1/16) G2(1/16) C3(1/16) G2(1/16) H2(1/16) G2(1/16) H2(1/16) G2(1/16)

'Seal: Kiss From A Rose
' :
'G2(1/16) A2(1/16) Ais2(1/8) P(1/16) C3(1/16) Ais2(1/8) A2(1/8) G2(1/8) F2(1/8) G2(1/8) P(1/8) G2(1/16) F2(1/16) G2(1/8) P(1/8) G2(1/16) A2(1/16) Ais2(1/8) P(1/16) C3(1/16) Ais2(1/8) A2(1/8) F2(1/8) A2(1/8) G2(1/8)

'Simpsons theme
'G2(1/8) P(1/16) H2(1/8) Cis3(1/8) E3(1/16) D3(1/8) P(1/16) H2(1/8) G2(1/8) E2(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16) D2(1/8) P(1/16) P(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16) Cis2(1/16) H2(1/16) E2(1/8) P(1/16) G2(1/16) G2(1/16) G2(1/16) G2(1/8)

'Smashing Pumpkins: Today
'D3(1/8) A2(1/8) E3(1/8) A2(1/8) D3(1/8) A2(1/8) Fis3(1/16) D3(1/16) A2(1/8) D3(1/8) A2(1/8) E3(1/8) A2(1/8) D3(1/8) A2(1/8) Fis3(1/16) D3(1/16) A2(1/8)

'Smoke On the Water
'C2(1/16) P(1/16) Fis2(1/16) P(1/16) F2(1/16) P(1/8) C2(1/16) P(1/16) E2(1/16) P(1/16) Fis2(1/16) F2(1/16) P(1/8) C2(1/16) P(1/16) Fis2(1/16) P(1/16) F2(1/16) P(1/8) Fis2(1/16) P(1/16) C2(1/16)

'SNAP: Rhythm Is A Dancer
'E3(1/16) P(1/16) C3(1/16) P(1/16) D3(1/16) P(1/16) C3(1/16) P(1/16) F2(1/16) P(1/16) F2(1/16) P(1/16) A2(1/16) P(1/16) F2(1/16) P(1/16) G2(1/16) P(1/16) G2(1/16) P(1/16) D2(1/16) P(1/16) G2(1/16) P(1/16) A2(1/16) P(1/16) A2(1/16) P(1/16) C3(1/16) P(1/16) A2(1/16) P(1/16)

'Doggy Dogg: Gz And Hustlaz
'G2(1/16) Ais2(1/16) C3(1/16) P(1/8) P(1/16) C2(1/8) P(1/4) P(1/8) P(1/16) D2(1/16) Fis2(1/16) P(1/8) F2(1/16) G2(1/16) P(1/16) Gis2(1/16) G2(1/16) P(1/16) G2(1/16) Ais2(1/16) P(1/16) Ais2(1/16) P(1/16) Ais2(1/16) P(1/16) Ais2(1/8) P(1/16) C3(1/16) P(1/8) C2(1/8)

'Spice Girls: Mama
'A2(1/8) P(1/16) H2(1/8) P(1/16) C3(1/8) H2(1/16) A2(1/16) G2(1/16) E2(1/8) P(1/16) P(1/16) H2(1/16) A2(1/16) G2(1/16) E2(1/8) G2(1/8) C2(1/8) P(1/4) P(1/8) A2(1/8) P(1/16) H2(1/8) P(1/16) C3(1/8) H2(1/16) A2(1/16) G2(1/16) E2(1/8) P(1/8) H2(1/16) A2(1/16) G2(1/16) E2(1/8) G2(1/8) A2(1/8)

'Star Trek
'C2(1/8) P(1/8) F2(1/16) A2(1/16) G2(1/8) Fis2(1/16) P(1/16) Fis2(1/16) D3(1/16) C3(1/8) P(1/4) A2(1/16) Ais2(1/16) C3(1/16) D3(1/16) Ais2(1/16) C3(1/8) P(1/16) Ais2(1/8) P(1/16) A2(1/8) P(1/16) A2(1/16) F2(1/16) A2(1/16) G2(1/8)

'Star trek: Communicator
'G3(1/16) A3(1/8) A3(1/16) A3(1/16) F3(1/8)

'Star Wars: Empire Strikes Back
'E2(1/8) P(1/16) E2(1/8) E2(1/16) E2(1/8) P(1/16) C2(1/8) G2(1/16) E2(1/8) P(1/16) C2(1/8) G2(1/16) E2(1/8) P(1/4) H2(1/8) P(1/16) H2(1/8) H2(1/16) H2(1/8) P(1/16) C3(1/8) G2(1/16) E2(1/8) P(1/16) C2(1/8) G2(1/16) E2(1/8)

'Star Wars: Force Theme
'D2(1/8) G2(1/8) G2(1/8) G2(1/8) A2(1/8) A2(1/8) Ais2(1/16) C3(1/16) Ais2(1/8) Ais2(1/8) Ais2(1/8) D2(1/8) D2(1/16) P(1/16) D2(1/8) G2(1/8) G2(1/8) A2(1/8) H2(1/16) H2(1/8) D2(1/8) H2(1/16) H2(1/8) G2(1/16) D3(1/16) C3(1/8) C3(1/8) C3(1/8) C3(1/8)

'Stevie Wonder: I Just Called
'C3(1/16) P(1/16) C3(1/8) P(1/16) A2(1/8) P(1/8) P(1/16) C3(1/8) H2(1/8) P(1/8) G2(1/16) P(1/16) H2(1/8) P(1/16) C3(1/8)

'Sting: Mad About You
'F2(1/16) E2(1/16) D2(1/16) F2(1/16) E2(1/8) P(1/2) P(1/8) G2(1/8) P(1/4) P(1/16) F2(1/16) E2(1/8) P(1/16) F2(1/16) E2(1/8) D2(1/8) F2(1/16) E2(1/16) D2(1/16) F2(1/16) E2(1/8)

'Strangers in the night
'F2(1/8) G2(1/8) G2(1/8) F2(1/8) G2(1/4) P(1/8) G2(1/8) F2(1/8) G2(1/8) A2(1/8) G2(1/8) F2(1/4) E2(1/8) F2(1/8) F2(1/8) E2(1/8) F2(1/4) P(1/8) F2(1/8) E2(1/8) F2(1/8) G2(1/8) F2(1/8) E2(1/4) P(1/8) D2(1/8) E2(1/8) E2(1/8) D2(1/8) E2(1/4) P(1/8) D2(1/8) E2(1/8) F2(1/8) E2(1/4) D2(1/4) Ais2(1/4) Ais2(1/4)

'Summer Night City
'C3(1/16) D3(1/16) F3(1/16) D3(1/16) C3(1/16) D3(1/8) A2(1/8) C3(1/16) D3(1/16) G2(1/16) A2(1/16) D2(1/8) C3(1/16) D3(1/16) F3(1/8) C3(1/16) D3(1/8)

'Superman
'C2(1/8) P(1/16) G2(1/8) P(1/16) P(1/16) G2(1/16) A2(1/16) G2(1/16) F2(1/16) G2(1/8) P(1/16) C2(1/16) C2(1/16) G2(1/8) P(1/8) G2(1/16) A2(1/16) G2(1/16) F2(1/16) A2(1/16) G2(1/8) P(1/8) C2(1/16) C2(1/16) H2(1/8) P(1/16) G2(1/8) P(1/16) C2(1/16) C2(1/16) H2(1/8) P(1/8)

'Tarkan: Sikidim (Hepsi sinin Mi)
'G2(1/8) A2(1/16) G2(1/16) A2(1/16) G2(1/16) A2(1/16) H2(1/16) A2(1/16) F2(1/16) F2(1/16) P(1/16) D3(1/8) C3(1/16) P(1/16) G2(1/8) A2(1/16) G2(1/16) A2(1/16) G2(1/16) A2(1/16) H2(1/16) Ais2(1/16) F2(1/16) F2(1/16) P(1/16) D3(1/8) C3(1/16)

'Tarkan: Simarik
'H2(1/16) H2(1/16) H2(1/16) Cis3(1/16) D3(1/8) D3(1/8) Cis3(1/16) D3(1/16) Cis3(1/16) D3(1/16) Cis3(1/8) Cis3(1/16) H2(1/16) A2(1/16) A2(1/16) A2(1/16) H2(1/16) Cis3(1/8) Cis3(1/8) H2(1/16) Cis3(1/16) H2(1/16) Cis3(1/16) H2(1/8) P(1/8) H2(1/16) H2(1/16) H2(1/16) Cis3(1/16) D3(1/8) D3(1/8) Cis3(1/16) D3(1/16) Cis3(1/16) D3(1/16) Cis3(1/8) Cis3(1/16) H2(1/16) A2(1/16) A2(1/16) A2(1/16) H2(1/16) Cis3(1/8) Cis3(1/8) P(1/8) H2(1/8) H2(1/8)

'Telefon 1
'H2(1/8) Gis3(1/8) Gis3(1/8) Fis3(1/8) Fis3(1/8) E3(1/8) Cis3(1/8) H2(1/8) P(1/16) H2(1/16) Cis3(1/8) Cis3(1/8) Fis3(1/8) Dis3(1/8) H2(1/8) P(1/4)

'Telefon 2
'H2(1/8) H3(1/8) H3(1/8) A3(1/8) A3(1/8) Gis3(1/8) E3(1/8) Cis3(1/8) P(1/16) Cis3(1/16) Dis3(1/8) Dis3(1/8) Fis3(1/8) Fis3(1/8) E3(1/8) P(1/4)

'Tetris
'E3(1/8) H2(1/16) C3(1/16) D3(1/8) C3(1/16) H2(1/16) A2(1/8) A2(1/16) C3(1/16) E3(1/8) D3(1/16) C3(1/16) H2(1/8) H2(1/16) C3(1/16) D3(1/8) E3(1/8) C3(1/8) A2(1/8) A2(1/8) P(1/16) P(1/16) D3(1/8) F3(1/16) A3(1/8) G3(1/16) F3(1/16) E3(1/8) C3(1/16) E3(1/8) D3(1/16) C3(1/16) H2(1/8) H2(1/16) C3(1/16) D3(1/8) E3(1/8) C3(1/8) A2(1/8) A2(1/8)

'Teletubies
'G2(1/8) P(1/16) G2(1/16) E2(1/16) P(1/16) G2(1/8) P(1/8) A2(1/8) P(1/8) F2(1/8) P(1/8) P(1/16) G2(1/8) P(1/16) G2(1/16) E2(1/16) P(1/16) G2(1/8) P(1/8) D2(1/8) P(1/4) G2(1/8) P(1/16) G2(1/16) E2(1/16) P(1/16) G2(1/8) P(1/8) A2(1/8) P(1/8) F2(1/8) P(1/8) P(1/16) G2(1/8) G2(1/8) P(1/8) H2(1/8) H2(1/8) P(1/8) C3(1/8) C3(1/8)

'Titanic: Theme
'C3(1/16) D3(1/16) E3(1/8) P(1/16) F3(1/16) E3(1/16) D3(1/16) C3(1/16) D3(1/16) G3(1/8) P(1/16) E3(1/16) D3(1/16) C3(1/8) P(1/16) A2(1/16) F2(1/16) G2(1/8) P(1/16) P(1/16) C3(1/16) D3(1/16) E3(1/8) P(1/16) F3(1/16) E3(1/16) D3(1/16) C3(1/16) D3(1/16) G3(1/8) P(1/16) E3(1/16) G3(1/16) A3(1/8) P(1/16) G3(1/16) E3(1/16) D3(1/8)

'Tom Jones: Not Unusual
'C2(1/16) F2(1/16) G2(1/16) P(1/16) A2(1/16) P(1/16) Ais2(1/16) P(1/16) C3(1/16) P(1/16) A2(1/16) A2(1/16) P(1/16) G2(1/8) P(1/16) C2(1/16) C2(1/16) C2(1/16) P(1/16) C2(1/8)

'Toni Braxton: Unbreak My Heart
'Gis2(1/8) Gis2(1/8) A2(1/8) A2(1/8) H2(1/8) H2(1/8) C3(1/8) C3(1/8) P(1/16) A2(1/8) A2(1/8) A2(1/8) H2(1/8) C3(1/8) C3(1/8) H2(1/8) P(1/16) Gis2(1/8) A2(1/8) A2(1/8) H2(1/8) C3(1/8) C3(1/8) C3(1/8) H2(1/8) A2(1/8) C3(1/8) C3(1/8) C3(1/8) C3(1/8) P(1/16) C3(1/8) C3(1/8) C3(1/8) H2(1/8) H2(1/8) H2(1/8)

'T
'Dis3(1/4) Dis3(1/8) D3(1/8) Dis3(1/8) C3(1/8) p(1/4) Dis3(1/4) Dis3(1/8) D3(1/8) Dis3(1/8) A3(1/8) p(1/4) Ais3(1/4) Ais3(1/8) A3(1/8) Ais3(1/8) G3(1/8) p(1/4) Ais3(1/4) Ais3(1/8) A3(1/8) Ais3(1/8) C4(1/8) p(1/4)

'U2: Gloria
'D2(1/16) E2(1/16) P(1/16) G2(1/16) A2(1/16) P(1/16) D2(1/16) E2(1/16) P(1/16) G2(1/16) A2(1/16) P(1/16) D2(1/16) E2(1/16) G2(1/16) P(1/16) H2(1/16) C3(1/16) H2(1/16) A2(1/16) P(1/16) G2(1/16) P(1/16) E2(1/16) P(1/16) G2(1/16) P(1/16) A2(1/16) P(1/16) E2(1/16)

'U96: Das Boot
'E2(1/8) P(1/16) Fis2(1/16) Cis2(1/16) Fis2(1/16) E2(1/16) Gis2(1/16) H2(1/8) P(1/16) Ais2(1/16) Gis2(1/16) Ais2(1/16) H2(1/16) Dis3(1/16) Fis3(1/8) P(1/4) P(1/8) Fis2(1/8) P(1/16) F2(1/16) Fis2(1/16) F2(1/16) Fis2(1/16) Ais2(1/16) Cis3(1/8) P(1/16) C3(1/16) Ais2(1/16) C3(1/16) Cis3(1/16) F3(1/16) Gis3(1/8)

'Ukko Nooa
'C2(1/16) P(1/16) C2(1/16) P(1/16) C2(1/16) P(1/16) E2(1/16) P(1/16) D2(1/16) P(1/16) D2(1/16) P(1/16) D2(1/16) P(1/16) F2(1/16) P(1/16) E2(1/16) P(1/16) E2(1/16) P(1/16) D2(1/16) P(1/16) D2(1/16) P(1/16) C2(1/16) P(1/4)

'Vaarilla on saari
'F2(1/16) F2(1/16) D2(1/16) C2(1/16) F2(1/8) D2(1/16) C2(1/16) F2(1/16) F2(1/16) G2(1/16) E2(1/16) F2(1/8) P(1/8) F2(1/16) F2(1/16) D2(1/16) C2(1/16) F2(1/8) D2(1/16) C2(1/16) F2(1/16) F2(1/16) G2(1/16) E2(1/16) F2(1/8)

'Venga Boys: Boom Boom Boom
'A2(1/16) P(1/16) A2(1/16) P(1/16) G2(1/16) P(1/16) F2(1/8) P(1/8) C2(1/16) C2(1/16) P(1/16) C2(1/16) P(1/16) G2(1/16) G2(1/16) P(1/16) F2(1/8) P(1/8) C2(1/16) C2(1/16) C2(1/16) P(1/16) C2(1/16) P(1/16) F2(1/16) P(1/16) A2(1/16) F2(1/16) P(1/8) F2(1/16) P(1/16) A2(1/8) P(1/16) G2(1/8) P(1/16) F2(1/8)

'Village People: YMCA
'D3(1/16) H2(1/16) P(1/4) H2(1/16) A2(1/16) G2(1/16) A2(1/16) H2(1/16) D3(1/16) P(1/16) H2(1/16) D3(1/16) P(1/16) E3(1/16) H2(1/16) P(1/4) H2(1/16) A2(1/16) G2(1/16) A2(1/16) H2(1/16) D3(1/16) P(1/16) H2(1/16) D3(1/16) P(1/16) E3(1/16) C3(1/16)

'We wish you a merry christmas
'D2(1/8) G2(1/8) G2(1/16) A2(1/16) G2(1/16) Fis2(1/16) E2(1/8) C2(1/8) E2(1/8) A2(1/8) A2(1/16) H2(1/16) A2(1/16) G2(1/16) Fis2(1/8) D2(1/4) H2(1/8) H2(1/16) C3(1/16) H2(1/16) A2(1/16) G2(1/8) E2(1/8) D2(1/16) D2(1/16) E2(1/8) A2(1/8) Fis2(1/8) G2(1/8)

'When the Saints go Marching In
'C2(1/16) E2(1/16) F2(1/16) G2(1/8) C2(1/16) E2(1/16) F2(1/16) G2(1/8) C2(1/16) E2(1/16) F2(1/16) G2(1/8) E2(1/8) C2(1/8) E2(1/8) D2(1/8) E2(1/8) D2(1/16) C2(1/8) E2(1/8) G2(1/8) G2(1/16) F2(1/8) E2(1/16) F2(1/16) G2(1/8) E2(1/8) C2(1/8) D2(1/8) C2(1/8)

'Will Smith: Men In Black
'C2(1/8) P(1/8) Fis2(1/16) P(1/16) C2(1/16) P(1/16) G2(1/16) P(1/16) G2(1/16) P(1/16) G2(1/16) P(1/4) G2(1/16) P(1/16) Gis2(1/16) P(1/16) G2(1/16) P(1/16) Fis2(1/16) P(1/16) F2(1/8) P(1/8) G2(1/8)

'Will Smith: Miami
'A3(1/8) P(1/8) G3(1/8) P(1/2) E3(1/8) E3(1/8) E3(1/8) E3(1/8) E3(1/8)

'X-Files
'C2(1/8) E2(1/8) D2(1/8) E2(1/8) A2(1/8) E2(1/8) P(1/4) C2(1/8) E2(1/8) D2(1/8) E2(1/8) A2(1/8) E2(1/8) P(1/4) C3(1/8) H2(1/8) A2(1/8) G2(1/8) A2(1/8) E2(1/8)

'X-mas:
'A2(1/8) A2(1/16) G2(1/16) Fis2(1/8) E2(1/8) D2(1/8) E2(1/8) Fis2(1/8) D2(1/8) E2(1/16) Fis2(1/16) G2(1/16) E2(1/16) Fis2(1/8) P(1/16) E2(1/16) D2(1/8) Cis2(1/8) D2(1/8)

'Zwampe
'C3(1/8) H2(1/8) A2(1/8) P(1/16) C3(1/8) C3(1/16) H2(1/8) A2(1/8) P(1/16) P(1/16) A2(1/8) F2(1/8) A2(1/8) H2(1/16) H2(1/8) H2(1/8) P(1/16) P(1/16)